@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: log.c,v 1.29 2003/01/08 09:31:37 bazsi Exp $
+ * $Id: log.c,v 1.32 2003/10/15 08:26:44 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -86,11 +86,28 @@ static void parse_log_msg(struct log_info *lm, UINT32 length, UINT8 *data, UINT8
 
 	/* If the next chars look like a date, then read them as a date. */
 	if (left >= 15) {
-  	        /* Expected buffer format: MMM DD HH:MM:SS ... */
+                struct tm tm, *nowtm;
 
-	        if (src[3] == ' ' && src[6] == ' ' &&
-		    src[9] == ':' && src[12] == ':') {
-	                struct tm tm, *nowtm;
+		if (left >= 21 &&
+		    src[3] == ' ' && src[6] == ' ' && src[11] == ' ' &&
+		    src[14] == ':' && src[17] == ':' && src[20] ==':') {
+			/* PIX time stamp, format: MMM DD YYYY HH:MM:SS: */
+			
+			src[20] = 0;
+			memset(&tm, 0, sizeof(tm));
+			strptime(src, "%b %e %Y %H:%M:%S", &tm);
+			tm.tm_isdst = -1;
+			lm->date = ol_string_alloc(16);
+			strftime(lm->date->data, 16, "%b %e %H:%M:%S", &tm);
+			lm->date->length--;
+			src[20] = ':';
+			src += 21;
+			left -= 21;
+			lm->stamp = mktime(&tm);
+		}
+	        else if (src[3] == ' ' && src[6] == ' ' &&
+		         src[9] == ':' && src[12] == ':') {
+	  	        /* Expected buffer format: MMM DD HH:MM:SS ... */
 
 			/* Just read the buffer data into a textual
 			   datestamp. */
@@ -104,7 +121,7 @@ static void parse_log_msg(struct log_info *lm, UINT32 length, UINT8 *data, UINT8
 			strptime(lm->date->data, "%b %e %H:%M:%S", &tm);
 			tm.tm_isdst = -1;
 			tm.tm_year = nowtm->tm_year;
-			if (tm.tm_mon > nowtm->tm_mon)
+			if (tm.tm_mon > nowtm->tm_mon + 1)
 				tm.tm_year--;
 			lm->stamp = mktime(&tm);
 		}
