@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: sources.c,v 1.36 2002/10/28 08:33:30 bazsi Exp $
+ * $Id: sources.c,v 1.37 2003/01/08 09:31:37 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -42,6 +42,7 @@
 
 #include "sources.c.x"
 #include "nscache.h"
+
 /* CLASS:
      (class
        (name log_reader)
@@ -54,6 +55,7 @@
 	 (max_log_line simple UINT32)
 	 (pad_size simple UINT32)
 	 (msg_flags simple UINT32)
+	 (bad_hostname special-struct regex_t #f regfree)
          (next object log_handler)))
 */
 
@@ -65,7 +67,7 @@ do_handle_line(struct log_reader *self,
 {
 	struct log_info *logmsg;
 
-	logmsg = make_log_info(length, data, self->prefix, self->msg_flags);
+	logmsg = make_log_info(length, data, self->prefix, self->msg_flags, &self->bad_hostname);
 	if (addrlen) {
 		logmsg->saddr = sockaddr2address_info(addrlen, addr);
 	}
@@ -155,6 +157,7 @@ make_log_reader(UINT32 dgram,
 		UINT32 max_log_line,
 		UINT32 pad_size,
 		UINT32 msg_flags,
+		UINT8 *hostname_re,
 		struct log_handler *next)
 {
 	NEW(log_reader, self);
@@ -167,7 +170,10 @@ make_log_reader(UINT32 dgram,
 	self->pad_size = pad_size;
 	self->msg_flags = msg_flags;
 	self->buffer = ol_space_alloc(self->max_log_line);
-	
+	if (hostname_re == NULL)
+		regcomp(&self->bad_hostname, "^$", REG_NOSUB | REG_EXTENDED);
+	else
+		regcomp(&self->bad_hostname, hostname_re, REG_NOSUB | REG_EXTENDED);
 	return &self->super;
 }
 
